@@ -35,11 +35,6 @@ ERC20_APPROVE_ABI = """[{"constant":false,"inputs":[{"name":"_spender","type":"a
 
 ERC20_TRANSFER_ABI = """[{"constant":false,"inputs":[{"name":"recipient","type":"address"},{"name":"amount","type":"uint256"}],"name":"transfer","outputs":[{"name":"","type":"bool"}],"payable":false,"stateMutability":"nonpayable","type":"function"}]"""
 
-def record_transaction(redis_client, user_id: str, chain: str, tx_hash: str) -> None:
-    key = f"user:tx:{user_id}:{chain}"
-    redis_client.rpush(key, tx_hash)
-    print(f"Recorded transaction {tx_hash} on {chain} for user {user_id}")
-
 def mpc_transfer(mpc_address: WalletAddress, destination, chain_raw, token_raw, token_address, amount):
     tx_hash = None
     try:
@@ -135,24 +130,17 @@ def get_token_address(chain, token):
         return f"Get token address failed. Error: {str(e)}"
 
 def transfer(receiver: str, amount: float, step: any, chain: str = "base", token: str = "usdc", **kwargs: Any) -> Dict[str, Any]:
-    print(f"receiver: {receiver}, amount: {amount}, chain: {chain}, token: {token}, step: {step}")
+    print(f"receiver: {receiver}, amount: {amount}, chain: {chain}, token: {token}, step: {step}", flush=True)
     
     chain_raw = chain.lower()
     executor = kwargs.get("executor")
     redis_client = kwargs.get("redis_client")
-    spender_info = kwargs.get('spender')
     providers = kwargs.get("providers")
-    executor_balance = kwargs.get("executor_balance")
     run_mode = get_user_action_mode(redis_client, executor)
 
     if not providers or chain_raw not in providers:
         raise ValueError(f"Provider for chain {chain} not found")
     
-    spender_address = spender_info[chain_raw]['control_address']
-    control_contract = spender_info[chain_raw]['control_contract']
-    sender_address = spender_info[chain_raw]['sender_address']
-    private_key = spender_info[chain_raw]['sender_private_key']
-    blockchain_explore = providers[chain_raw]['scan']
     w3 = get_web3(providers, chain_raw)
     eth_w3 = get_web3(providers, 'eth')
     token_raw = token.lower()
@@ -163,22 +151,13 @@ def transfer(receiver: str, amount: float, step: any, chain: str = "base", token
         token_address = w3.to_checksum_address(token_address)
     print(f"token address: {token_address}", flush=True)
     
-    # print(f"w3: {w3}", flush=True)
-
     if run_mode.lower() == 'auto':
-        return handle_auto_transfer(w3, eth_w3, mpc_address, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore, executor_balance)
+        return handle_auto_transfer(w3, eth_w3, mpc_address, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw)
     else:
         return handle_manual_transfer(w3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw)
 
-def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore, executor_balance):
-    
+def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw):
     if token_raw == 'usdc' and chain_raw == 'base':
-        amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
-        # try:
-        #     decrease_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
-        # except Exception as e:
-        #     print(f"Exception occurred: {e}", flush=True)
-        #     return {'result': {"content": f"{e}", "code": 500}, 'action': None, 'next_action': None}
         try:
             code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
             if code != 200:
@@ -189,12 +168,9 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
 
             print(f"to: {to}, executor: {executor}", flush=True)
             info = mpc_transfer(mpc_address, to, chain_raw, token_raw, token_address, amount)
-            # if info['code'] != 200:
-            #     increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
             return {'result': info, 'action': None, 'next_action': None}
         except Exception as e:
-            # increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
-            return handle_transaction_error(e, control_contract, w3)
+            return handle_auto_transfer_error(e)
     else:
         token = token_raw.upper()
         if token_raw in ['btc', 'cbbtc', 'wbtc']:
@@ -253,33 +229,33 @@ def handle_manual_transfer(w3: Web3, eth_w3, executor, receiver, amount, token_a
     action = Action(msg=None, type='wallet', data=action_data.__dict__)
     return {'result': {"code": 200, "content": "Manual transfer parameters are constructed"}, 'action': action.__dict__, 'next_action': None}
 
-def handle_insufficient_allowance(w3, eth_w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client):
-    amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
-    action_params = {
-        "func": "approve",
-        "chainId": CHAIN_ID_MAPPING[chain_raw],
-        'contract': token_address,
-        '_spender': spender_address,
-        '_value': amount_to_transfer,
-        'abi': ERC20_APPROVE_ABI
-    }
-    action_data = ActionData(func='', group='', params=action_params)
-    action = Action(msg=None, type='wallet', data=action_data.__dict__)
+# def handle_insufficient_allowance(w3, eth_w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client):
+#     amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
+#     action_params = {
+#         "func": "approve",
+#         "chainId": CHAIN_ID_MAPPING[chain_raw],
+#         'contract': token_address,
+#         '_spender': spender_address,
+#         '_value': amount_to_transfer,
+#         'abi': ERC20_APPROVE_ABI
+#     }
+#     action_data = ActionData(func='', group='', params=action_params)
+#     action = Action(msg=None, type='wallet', data=action_data.__dict__)
 
-    code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
-    if code != 200:
-        return {'result': {"content": f"{receiver_address}", "code": 420}, 'action': None, 'next_action': None}
+#     code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
+#     if code != 200:
+#         return {'result': {"content": f"{receiver_address}", "code": 420}, 'action': None, 'next_action': None}
 
-    next_params = {
-        'receiver': w3.to_checksum_address(receiver_address),
-        'amount': amount,
-        'chain': chain_raw,
-        'token': token_raw,
-        'run_mode': 'auto'
-    }
-    next_action_data = ActionData(func='transfer', group='transfer', params=next_params)
-    next_action = Action(msg=None, type='backend', data=next_action_data.__dict__)
-    return {'result': {"code": 200, "content": "Insufficient allowance, proceeding with approval."}, 'action': action.__dict__, 'next_action': next_action.__dict__}
+#     next_params = {
+#         'receiver': w3.to_checksum_address(receiver_address),
+#         'amount': amount,
+#         'chain': chain_raw,
+#         'token': token_raw,
+#         'run_mode': 'auto'
+#     }
+#     next_action_data = ActionData(func='transfer', group='transfer', params=next_params)
+#     next_action = Action(msg=None, type='backend', data=next_action_data.__dict__)
+#     return {'result': {"code": 200, "content": "Insufficient allowance, proceeding with approval."}, 'action': action.__dict__, 'next_action': next_action.__dict__}
 
 def handle_incorrect_network(w3, eth_w3, executor, receiver, amount, chain_raw, token_raw, redis_client):
     params = {"chainId": CHAIN_ID_MAPPING[chain_raw]}
@@ -325,6 +301,10 @@ def maybe_send_transaction(w3: Web3, control_contract, sender_address, token, ex
     signed_tx = w3.eth.account.sign_transaction(tx, private_key)
     return True, w3.eth.send_raw_transaction(signed_tx.rawTransaction)
 
+def handle_auto_transfer_error(e):
+    message = f"Transfer failed with unknown error: {e}"
+    return {'result': {"content": message, "status": 0, "code": 500}, 'action': None, 'next_action': None}
+
 def handle_transaction_error(e, control_contract, w3):
     name, params = decode_custom_error(control_contract.abi, w3, str(e))
     if not name:
