@@ -24,9 +24,10 @@ def show_account_info(step: any, **kwargs):
     executor = kwargs.get('executor')
     providers = kwargs.get("providers")
     w3 = providers['base']['w3']
+    mpc_address = kwargs.get('mpc_address')
     result = {}
     account_info = get_account_info(redis_client, executor)
-    user_assets = get_user_assets(redis_client, executor, w3)
+    user_assets = get_user_base_assets(mpc_address)
     result['remain_balance'] = account_info['remain_balance']
     result['address'] = executor
     result['assets'] = user_assets
@@ -60,6 +61,9 @@ def get_extra_funds(redis_client, account_id):
     extra_funds = redis_client.hget(f'user_funds:{account_id}', 'extra_funds')
     return int(extra_funds or 0)
 
+def get_base_usdc_mpc_balance(mpc_address):
+    return float(mpc_address.balance('usdc'))
+
 def get_base_usdc_balance(address: str, w3: Web3) -> float:
     address = Web3.to_checksum_address(address)
     # usdc_address = Web3.to_checksum_address(TOKEN_MAPPING['base']['usdc']['address'])
@@ -71,21 +75,33 @@ def get_base_usdc_balance(address: str, w3: Web3) -> float:
     raw_balance = usdc_contract.functions.balanceOf(address).call()
     return raw_balance
 
-def get_user_assets(redis_client, user_id, w3):
+def get_user_base_assets(mpc_address):
     result = []
-    chain = 'base-sepolia'
-    user_id = user_id.lower()
-    chain = chain.lower()   
-    key = f"mpc_address:{user_id}:{chain}"
-    
-    redis_data = redis_client.hgetall(key)
-    if not redis_data:
-        result.append({'chain': 'Base', 'token': 'USDC', 'amount': 0 })
-        return result
-    else:
-        usdc_balance = get_base_usdc_balance(redis_data['wallet_address'], w3)
+    try:
+        usdc_balance = get_base_usdc_mpc_balance(mpc_address)
         result.append({'chain': 'Base', 'token': 'USDC', 'amount': usdc_balance})
-        return result
+    except Exception as e:
+        print(f"Error getting USDC balance: {e}", flush=True)
+        result.append({'chain': 'Base', 'token': 'USDC', 'amount': 0 })
+    return result
+
+# def get_user_assets(redis_client, user_id, w3, mpc_address):
+#     result = []
+#     chain = 'base-sepolia'
+#     user_id = user_id.lower()
+#     chain = chain.lower()   
+#     key = f"mpc_address:{user_id}:{chain}"
+    
+#     redis_data = redis_client.hgetall(key)
+#     if not redis_data:
+#         result.append({'chain': 'Base', 'token': 'USDC', 'amount': 0 })
+#         return result
+#     else:
+#         # usdc_balance = get_base_usdc_balance(redis_data['wallet_address'], w3)
+#         usdc_balance = get_base_usdc_mpc_balance(mpc_address)
+#         print(f"usdc_balance: {usdc_balance}", flush=True)
+#         result.append({'chain': 'Base', 'token': 'USDC', 'amount': usdc_balance})
+#         return result
 
 def generate_complete_markdown(user_address, ai_balance, assets):
     """
@@ -102,13 +118,13 @@ def generate_complete_markdown(user_address, ai_balance, assets):
     # Header with user address and AI balance
     header = (
         f"**Account address:** `{user_address}`\n"
-        f"**Inference fee remain balance:** ${convert_to_value(ai_balance, 6)}\n"
+        f"**AI service fee balance:** ${convert_to_value(ai_balance, 6)}\n"
         f"**Assets:**\n\n"
     )
     
     # Define the table structure
     table_header = "| Chain | Token | Amount |\n|-------|-------|--------|\n"
-    rows = [f"| {asset['chain']} | {asset['token'].upper()} | {convert_to_value(asset['amount'], 6)} |" for asset in assets]
+    rows = [f"| {asset['chain']} | {asset['token'].upper()} | {asset['amount']} |" for asset in assets]
     table = table_header + "\n".join(rows)
     
     # Combine the header and table into the final Markdown output
